pyControl4 API documentation

# Package `pyControl4`

## Sub-modules

`pyControl4.account`

  Authenticates with the Control4 API, retrieves account and registered controller info, and retrieves a bearer token for connecting to a Control4 …

`pyControl4.alarm`

  Controls Control4 security panel and contact sensor (door, window, motion) devices.

`pyControl4.blind`

  Controls Control4 blind devices.

`pyControl4.director`

  Handles communication with a Control4 Director, and provides functions for getting details about items on the Director.

`pyControl4.error_handling`

  Handles errors recieved from the Control4 API.

`pyControl4.light`

  Controls Control4 Light devices.

`pyControl4.relay`

  Controls Control4 Relay devices. These can include locks, and potentially other types of devices.

`pyControl4.websocket`

  Handles Websocket connections to a Control4 Director, allowing for real-time updates using callbacks.